@@ -2,38 +2,47 @@ from distutils import log
 import distutils.command.sdist as orig
 import os
 import sys
-import io
 import contextlib
-from glob import iglob
+from itertools import chain
 
-import ordered_set
-
-from .py36compat import sdist_add_defaults
-
-import pkg_resources
+from .._importlib import metadata
+from .build import _ORIGINAL_SUBCOMMANDS
 
 _default_revctrl = list
 
 
 def walk_revctrl(dirname=''):
     """Find all files under revision control"""
-    for ep in pkg_resources.iter_entry_points('setuptools.file_finders'):
+    for ep in metadata.entry_points(group='setuptools.file_finders'):
         for item in ep.load()(dirname):
             yield item
 
 
-class sdist(sdist_add_defaults, orig.sdist):
+class sdist(orig.sdist):
     """Smart sdist that finds anything supported by revision control"""
 
     user_options = [
-        ('formats=', None,
-         "formats for source distribution (comma-separated list)"),
-        ('keep-temp', 'k',
-         "keep the distribution tree around after creating " +
-         "archive file(s)"),
-        ('dist-dir=', 'd',
-         "directory to put the source distribution archive(s) in "
-         "[default: dist]"),
+        ('formats=', None, "formats for source distribution (comma-separated list)"),
+        (
+            'keep-temp',
+            'k',
+            "keep the distribution tree around after creating " + "archive file(s)",
+        ),
+        (
+            'dist-dir=',
+            'd',
+            "directory to put the source distribution archive(s) in " "[default: dist]",
+        ),
+        (
+            'owner=',
+            'u',
+            "Owner name used when creating a tar file [default: current user]",
+        ),
+        (
+            'group=',
+            'g',
+            "Group name used when creating a tar file [default: current group]",
+        ),
     ]
 
     negative_opt = {}
@@ -99,6 +108,10 @@ class sdist(sdist_add_defaults, orig.sdist):
             if orig_val is not NoValue:
                 setattr(os, 'link', orig_val)
 
+    def add_defaults(self):
+        super().add_defaults()
+        self._add_defaults_build_sub_commands()
+
     def _add_defaults_optional(self):
         super()._add_defaults_optional()
         if os.path.isfile('pyproject.toml'):
@@ -111,14 +124,25 @@ class sdist(sdist_add_defaults, orig.sdist):
             self.filelist.extend(build_py.get_source_files())
             self._add_data_files(self._safe_data_files(build_py))
 
+    def _add_defaults_build_sub_commands(self):
+        build = self.get_finalized_command("build")
+        missing_cmds = set(build.get_sub_commands()) - _ORIGINAL_SUBCOMMANDS
+        # ^-- the original built-in sub-commands are already handled by default.
+        cmds = (self.get_finalized_command(c) for c in missing_cmds)
+        files = (c.get_source_files() for c in cmds if hasattr(c, "get_source_files"))
+        self.filelist.extend(chain.from_iterable(files))
+
     def _safe_data_files(self, build_py):
         """
-        Extracting data_files from build_py is known to cause
-        infinite recursion errors when `include_package_data`
-        is enabled, so suppress it in that case.
+        Since the ``sdist`` class is also used to compute the MANIFEST
+        (via :obj:`setuptools.command.egg_info.manifest_maker`),
+        there might be recursion problems when trying to obtain the list of
+        data_files and ``include_package_data=True`` (which in turn depends on
+        the files included in the MANIFEST).
+
+        To avoid that, ``manifest_maker`` should be able to overwrite this
+        method and avoid recursive attempts to build/analyze the MANIFEST.
         """
-        if self.distribution.include_package_data:
-            return ()
         return build_py.data_files
 
     def _add_data_files(self, data_files):
@@ -143,8 +167,7 @@ class sdist(sdist_add_defaults, orig.sdist):
                 return
         else:
             self.warn(
-                "standard file not found: should have one of " +
-                ', '.join(self.READMES)
+                "standard file not found: should have one of " + ', '.join(self.READMES)
             )
 
     def make_release_tree(self, base_dir, files):
@@ -165,10 +188,9 @@ class sdist(sdist_add_defaults, orig.sdist):
         if not os.path.isfile(self.manifest):
             return False
 
-        with io.open(self.manifest, 'rb') as fp:
+        with open(self.manifest, 'rb') as fp:
             first_line = fp.readline()
-        return (first_line !=
-                '# file GENERATED by distutils, do NOT edit\n'.encode())
+        return first_line != '# file GENERATED by distutils, do NOT edit\n'.encode()
 
     def read_manifest(self):
         """Read the manifest file (named by 'self.manifest') and use it to
@@ -190,46 +212,3 @@ class sdist(sdist_add_defaults, orig.sdist):
                 continue
             self.filelist.append(line)
         manifest.close()
-
-    def check_license(self):
-        """Checks if license_file' or 'license_files' is configured and adds any
-        valid paths to 'self.filelist'.
-        """
-        opts = self.distribution.get_option_dict('metadata')
-
-        files = ordered_set.OrderedSet()
-        try:
-            license_files = self.distribution.metadata.license_files
-        except TypeError:
-            log.warn("warning: 'license_files' option is malformed")
-            license_files = ordered_set.OrderedSet()
-        patterns = license_files if isinstance(license_files, ordered_set.OrderedSet) \
-            else ordered_set.OrderedSet(license_files)
-
-        if 'license_file' in opts:
-            log.warn(
-                "warning: the 'license_file' option is deprecated, "
-                "use 'license_files' instead")
-            patterns.append(opts['license_file'][1])
-
-        if 'license_file' not in opts and 'license_files' not in opts:
-            # Default patterns match the ones wheel uses
-            # See https://wheel.readthedocs.io/en/stable/user_guide.html
-            # -> 'Including license files in the generated wheel file'
-            patterns = ('LICEN[CS]E*', 'COPYING*', 'NOTICE*', 'AUTHORS*')
-
-        for pattern in patterns:
-            for path in iglob(pattern):
-                if path.endswith('~'):
-                    log.debug(
-                        "ignoring license file '%s' as it looks like a backup",
-                        path)
-                    continue
-
-                if path not in files and os.path.isfile(path):
-                    log.info(
-                        "adding license file '%s' (matched pattern '%s')",
-                        path, pattern)
-                    files.add(path)
-
-        self.filelist.extend(sorted(files))
