@@ -556,23 +556,9 @@ class ConfigMetadataHandler(ConfigHandler["DistributionMetadata"]):
             'platforms': parse_list,
             'keywords': parse_list,
             'provides': parse_list,
-            'requires': self._deprecated_config_handler(
-                parse_list,
-                "The requires parameter is deprecated, please use "
-                "install_requires for runtime dependencies.",
-                due_date=(2023, 10, 30),
-                # Warning introduced in 27 Oct 2018
-            ),
             'obsoletes': parse_list,
             'classifiers': self._get_parser_compound(parse_file, parse_list),
             'license': exclude_files_parser('license'),
-            'license_file': self._deprecated_config_handler(
-                exclude_files_parser('license_file'),
-                "The license_file parameter is deprecated, "
-                "use license_files instead.",
-                due_date=(2023, 10, 30),
-                # Warning introduced in 23 May 2021
-            ),
             'license_files': parse_list,
             'description': parse_file,
             'long_description': parse_file,
